!!! warning "Under construction"

This section highlights the internal working of JAXspec, and the hypothesis and modelisations used
to perform the inference. It is not necessary to read this section to use JAXspec, but it can be
useful to understand the underlying assumptions and the limitations of the library.
